<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Spastroje regjistrin</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rifreskoje</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Jeni i sigurt se doni të spastrohet regjistri?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Sot</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 ditë</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 javë</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 muaj</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 muaj</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportoje</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Krejt</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Hyrje</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Nisje</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Fikje</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Mirëfilltësim identiteti</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Kontrolli Diskretional</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Kontrolli Obligatorike</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Remote</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Audita Dokumente</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Tjetër</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Po eksportohet…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksportim i suksesshëm</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Eksportimi dështoi</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Drejtoria e eksportimeve s’është e passhme. Ju lutemi, zgjidhni një drejtori tjetër për veprimin e eksportimit.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksporto Kartelë</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Periudhë:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Gjendje:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Lloj Akti:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Veprim:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Emër përdoruesi:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zë nisjesh</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zë fikjesh</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Zë hyrjesh</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Lloj Auditimi:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Aplikacion:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Nënmodul:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Diagnostikoje</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Urgjencë</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Sinjalizim</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Njoftim</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ndiqe</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Superkritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Kartela regjistër është e zbrazët</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Parës Regjistri</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Parësi i Regjistrave është një mjet i dobishëm për parje regjistrash sistemi.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>S’ka përfundime kërkimi</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivel</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Përdorues</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Burim</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Veprim</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Lloj Akti</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Emër përdoruesi</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivel:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Datë dhe Kohë:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Info:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nëjë</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Përdorues:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Emër Kartele</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Kohë Ndryshimi</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Fajll Core</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Emër Përdoruesi</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Offset</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Datë dhe Kohë</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Regjistër Sistemi</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Regjistër Kerneli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Regjistër Nisjesh</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Regjistër dpkg-je</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Regjistër Kwin-i</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Regjistër Xorg-u</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Regjistër Aplikacionesh</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Akt Nisjeje-Fikjeje</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Regjistër dnf-je</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Regjistër Tjetër</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Regjistër Vetjak</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Regjistër Auditimesh</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Regjistër Coredump-i</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>S’u arrit të merreshin hollësi vithisjeje, ju lutemi, instaloni systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>S’keni leje ta shini</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Shkallë sigurie për sistemin e tanishëm: e lartë
 auditim: vetëm përgjegjësit mund të shohin regjistër auditimesh</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation>Regjistro Audita nuk ekziston.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Eksporto regjistra te shtegu i përcaktuar</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>SHTEG</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Eksporto regjistra te shtigjet e përcaktuar</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>LLOJ</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Eksporto regjistra të aplikacioneve të dhëna të vetëzhvilluara</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>SELF APPNEM</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Eksporto regjistra brenda një periudhe të dhënë kohore</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>PERIUDHË</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Eksporto regjistra me një shkallë të caktuar diagnostikimi</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>SHKALLË</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>GJENDJE NISJEJE</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Eksporto regjistra nisjeje(no-klu) brenda një gjendjeje të caktuar</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Eksporto regjistra “boot-shutdown-event” ose auditimi brenda një lloji të caktuar aktesh</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>LLOJ AKTI</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Eksporto regjistra bazuar në përfundime kërkimi për fjalëkyçe</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>FJALËKYÇE</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Raporto informacione për coredump.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Eksporto regjistra bazuar në nënmodel aplikacioni</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>NËNMODUL</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval rifreskimi</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10s</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1m</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5m</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Pa rifreskim</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportoji Krejt</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Rifreskoje Tani</translation>
    </message>
</context>
</TS>